#!/bin/sh
#args: possible db2 user names & directories

# assumes:
#	db2 is installed in db2 home directories
# 	only a single version of db2 is registered/machine

# tags to help synchornize parsing

TAG='~~'
PTAG='~p~'	# profile
GPTAG='~gp~'	# global profile
ITAG='~i~'	# instance
LTAG='~l~'	# license
DBTAG='~db~'	# database
EDBTAG='~edb~'	# end database
STAG='~s~'	# status 
ETAG='~e~'	# ending
CTAG='~c~'	# container
LANG=C      # set locale to C
export LANG

localgetent()
{
	getent $1 2>/dev/null
	if [ $? -ne 0 ]
	then
		cat /etc/$1
	fi
}

INSTANCES=
for i in $*
do
  case $i in
    -u)
      shift
      INSTANCES="$INSTANCES $1"
      # get home directory for user
      OS=`uname`
	  #AIX not support getent lsuser cmd used instead
	  if [ "$OS" = "AIX" ]
	  then
        user=`lsuser -a home ALL |grep -w "^$1" |sed -e "s/[^=]*=//"`
	  else
    	user=`localgetent passwd |grep "^$1:" |awk -F: '{print $6}'`
	  fi
      if [ -d ${user}/sqllib ]
      then
        PATH=$user/sqllib/bin:$user/sqllib/adm:$user/sqllib/misc:$PATH
        LD_LIBRARY_PATH=$user/sqllib/lib:$LD_LIBRARY_PATH
      fi
      shift
      ;;
    -d)
      shift
      dir=$1
      if [ -d ${dir}/sqllib ]
      then
        PATH=$dir/sqllib/bin:$dir/sqllib/adm:$dir/sqllib/misc:$PATH
        LD_LIBRARY_PATH=$dir/sqllib/lib:$LD_LIBRARY_PATH
      fi
      shift
      ;;
  esac
done # 	for i
export PATH LD_LIBRARY_PATH
echo "PATH=$PATH"
unset DB2INSTANCE

# find instance list/install directories
db2ilist -a > /dev/null 2>&1
stat=$?
echo "$TAG: instance info"
echo "$STAG: $stat."

LINECOUNT=`db2ilist -a | grep "/" | wc -l`
if [ $LINECOUNT -gt 0 ]
then
	INSTANCE_LIST=`db2ilist -a | grep "/" | while read line
	do
	  set $line x
	  echo $1
	done
	`
else
	INSTANCE_LIST=`db2ilist -a | while read line
	do
	  set $line x
	  echo $1
	done
	`
fi

echo $INSTANCE_LIST
z=
if [ -n "$INSTANCES" ]
then
    for x in $INSTANCES
    do
        for y in $INSTANCE_LIST
        do
            if [ "x$x" = "x$y" ]
            then
                z="$z $x"
            fi
        done
    done
    if [ -n "$z" ]
    then
        INSTANCE_LIST=$z
        echo "overriding instance list with: $INSTANCE_LIST"
    fi
fi

echo "$TAG: install info"
echo "$STAG: $stat."
# need install directories to get DB2DIR
INSTALL_LIST=`db2ilist -a | while read line
do
  set $line x
  echo $3
done | uniq
`
db2ilist -a 

# get system info
#design: note dbas server name is here
# global profile
echo "$GPTAG: db2set -g"
db2set -g
echo "$STAG: $?."
echo "$ETAG"

# license info - must be member of OS db2 admin group
echo "$LTAG: license info"
db2licm -l
echo "$STAG: $?."
echo "$ETAG"


# get instance info
for DB2INSTANCE in $INSTANCE_LIST
do
  export DB2INSTANCE
  echo "$ITAG $DB2INSTANCE"

  echo "$TAG: attach test"
  db2 <<!
    attach to $DB2INSTANCE
!
  stat=$?
  echo ""
  echo "$STAG: $stat."
  echo "$ETAG"

  echo "$TAG: dbm config"
  db2 <<!
    attach to $DB2INSTANCE
    get dbm config
!
  stat=$?
  echo ""
  echo "$STAG: $stat."
  echo "$ETAG"

  echo "$TAG: db2level -g"
  db2level
  stat=$?
  echo ""
  echo "$STAG: $stat."
  echo "$ETAG"

  echo "$PTAG: db2set -i"
  db2set -i $DB2INSTANCE
  echo "$STAG: $?."
  echo "$ETAG"

  echo "$TAG: list db directory"
  db2 > /tmp/$$.tmp <<!
    attach to $DB2INSTANCE
    list db directory
!
  stat=$?
  echo ""
  cat /tmp/$$.tmp
  echo ""
  echo "$STAG: $stat."
  echo "$ETAG"

  DBLIST=`cat /tmp/$$.tmp | grep "Database alias" | sed 's/^.*=//g'`
  echo "$TAG"

  for DB in $DBLIST
  do
    echo "$DBTAG: get db config for: \"$DB\""
    echo "$PTAG"
    DB2CP=`db2 get db config for $DB | grep "Database code page" | sed 's/^.*=//g' | sed 's/ //g'`
    DB2CODEPAGE=$DB2CP
    export DB2CODEPAGE
    db2 terminate
    db2 <<!
      set client connect 2
      attach to $DB2INSTANCE
      connect to $DB
      get db config for $DB
      commit
      disconnect all
!
    stat=$?
    echo ""
    echo "$STAG: $stat."
    echo "$ETAG"

    if [ $stat -eq 0 ]
    then

      echo "$TAG: select tablespace info for: $DB"
      db2 -t > /tmp/$$.tmp <<!
        set client connect 2;
        attach to $DB2INSTANCE;
        connect to $DB;
        SELECT '$TAG', TBSPACEID, TBSPACE, BUFFERPOOLID, EXTENTSIZE, PAGESIZE FROM SYSCAT.TABLESPACES;
        commit;
        disconnect all;
!
      stat=$?
      echo ""
      cat /tmp/$$.tmp | grep $TAG 
      SPACEIDS=`cat /tmp/$$.tmp | grep $TAG | awk '{print $2}'`
      echo ""
      echo "$STAG: $stat."
      echo "$ETAG"

      echo "$TAG: list tablespaces for: $DB"
      db2 -t <<!
        set client connect 2;
        attach to $DB2INSTANCE;
        connect to $DB;
        list tablespaces show detail;
        commit;
        disconnect all;
!
      stat=$?
      echo ""
      echo "$STAG: $stat."
      echo "$ETAG"

      echo "$TAG: about to list all containers"
      for N in $SPACEIDS
      do
        echo "$CTAG: list tablespace containers for: $DB, tablespace id: \"$N\""
        db2 -t <<!
          set client connect 2;
          attach to $DB2INSTANCE;
          connect to $DB;
          list tablespace containers for $N show detail;
          commit;
          disconnect all;
!
        stat=$?
        echo ""
        echo "$STAG: $stat."
        echo "$ETAG"
      done

      echo "$TAG: select bufferpool info for: $DB"
      db2 -t <<!
        set client connect 2;
        attach to $DB2INSTANCE;
        connect to $DB;
        SELECT '$TAG', BUFFERPOOLID, BPNAME, PAGESIZE, NPAGES, ' ' FROM SYSCAT.BUFFERPOOLS;
        commit;
        disconnect all;
!
      stat=$?
      echo ""
      echo "$STAG: $stat."
      echo "$ETAG"
    fi  # if db exists
    echo $EDBTAG
  done	# for each database
done	# for each instance
echo ""
rm /tmp/$$.tmp
